<template>
  <div>
    <page-search-table @search="reload"></page-search-table>
    <!-- 数据表格 -->
    <ele-pro-table
      ref="table"
      :columns="columns"
      :datasource="datasource"
      height="calc(100vh - 430px)"
      full-height="calc(100vh - 116px)"
      tool-class="ele-toolbar-form"
      :selection.sync="selection"
      cache-key="dispatchManagePage1Table"
    >
      <!-- 表头工具栏 -->
      <template v-slot:toolbar>
        <el-button
          size="small"
          type="primary"
          icon="el-icon-plus"
          class="ele-btn-icon"
          @click="handleAddOrEdit('','add')"
        >
          新建
        </el-button>
        <el-button
          size="small"
          type="danger"
          el-icon-delete
          class="ele-btn-icon"
          @click="allDelBtn"
          :disabled="selection?.length === 0"
        >
          批量删除
        </el-button>
      </template>
      <!-- 操作 -->
      <template v-slot:action="{row}">
        <el-link
          type="primary"
          v-if="[0, 3].includes(row.processStatus)"
          :underline="false"
          icon="el-icon-plus"
          @click="sub(row)"
        >
          提交
        </el-link>
        <el-link
          type="primary"
          v-if="[0, 3].includes(row.processStatus)"
          :underline="false"
          icon="el-icon-edit"
          @click="handleAddOrEdit(row,'update')"
        >
          修改
        </el-link>
        <el-link
          type="primary"
          v-if="[2].includes(row.processStatus)&&row.status==0"
          :underline="false"
          icon="el-icon-edit"
          @click="handleDispatch(row,'update')">
          派单
        </el-link>
        <el-link
          type="primary"
          v-if="[2].includes(row.processStatus)&&[1].includes(row.status)"
          :underline="false"
          icon="el-icon-edit"
          @click="handleWithdraw(row,'update')">
          撤回
        </el-link>

        <el-popconfirm
          v-if="[0, 3].includes(row.processStatus)"
          class="ele-action"
          title="确定要删除此信息吗？"
          @confirm="remove([row.id])"
        >
          <template v-slot:reference>
            <el-link
              type="danger"
              :underline="false"
              icon="el-icon-delete"
            >
              删除
            </el-link>
          </template>
        </el-popconfirm>
      </template>
      <template v-slot:planName="{row}">
        <el-link
          type="primary"
          :underline="false"
          @click="handleDetail(row,'view')">
          {{ row.planName }}
        </el-link>
      </template>
    </ele-pro-table>
    <!-- 多选删除弹窗 -->
    <pop-modal
      :visible.sync="delVisible"
      content="是否确定删除？"
      @done="commitBtn"
    />
    <!--  新增/修改  -->
    <add-or-edit-dialog v-if="addOrEditDialogFlag" :addOrEditDialogFlag.sync="addOrEditDialogFlag"
                        ref="addOrEditDialogRef" @reload="reload"></add-or-edit-dialog>
    <detail-dialog v-if="detailDialogFlag" :detail-dialog-flag.sync="detailDialogFlag"
                   ref="detailDialogRef"></detail-dialog>
  </div>

</template>

<script>
import popModal from '@/components/pop-modal';
import {reviewStatus, reviewStatusEnum} from '@/enum/dict';
import dictMixins from "@/mixins/dictMixins";
import pageSearchTable from "./pageSearchTable.vue";

import addOrEditDialog from '@/views/transportManager/shipManage/dispatchManage/components/addOrEditDialog.vue'
import detailDialog from '@/views/transportManager/shipManage/dispatchManage/components/detailDialog.vue'
import {
  logisticSubmit, logistictrakplanDistributionAPI,
  logistictrakplanPageListAPI,
  logistictrakplanRemoveAPI, logistictrakplanwithdrawAPI
} from "@/api/transportManager/shipManage";

export default {
  mixins: [dictMixins],
  components: {
    addOrEditDialog,
    pageSearchTable,
    popModal,
    detailDialog
  },
  data() {
    return {
      selection: [],
      statusList: [
        {value: 0, label: '未开始'},
        {value: 1, label: '已派发'},
        {value: 2, label: '执行中'},
        {value: 2, label: '已完成'}
      ],
      delVisible: false,
      // 加载状态
      loading: false,
      addOrEditDialogFlag: false,
      detailDialogFlag: false,
    };
  },
  computed: {
    columns() {
      return [
        {
          width: 45,
          type: 'selection',
          columnKey: 'selection',
          align: 'center'
        },
        {
          columnKey: 'index',
          label: '序号',
          type: 'index',
          width: 55,
          align: 'center',
          showOverflowTooltip: true,
          fixed: 'left'
        },

        {
          prop: 'code',
          label: '计划编号',
          align: 'center',
          showOverflowTooltip: true,
          minWidth: 120,
          slot: 'code'
        },
        {
          prop: 'planName',
          label: '计划名称',
          align: 'center',
          showOverflowTooltip: true,
          minWidth: 120,
          slot: 'planName'
        },
        {
          prop: 'planTimeStart',
          label: '计划开始时间',
          align: 'center',
          slot: 'planTimeStart',
          showOverflowTooltip: true,
          minWidth: 120,
        },
        {
          prop: 'planTimeEnd',
          label: '计划结束时间',
          align: 'center',
          slot: 'planTimeEnd',
          showOverflowTooltip: true,
          minWidth: 120,
        },
        {
          prop: 'deptName',
          label: '负责部门',
          align: 'center',
          slot: 'deptName',
          showOverflowTooltip: true,
          minWidth: 120,
        },
        {
          prop: 'responsiblePersonName',
          label: '负责人',
          align: 'center',
          slot: 'responsiblePersonName',
          showOverflowTooltip: true,
          minWidth: 120,
        },
        {
          prop: 'createTime',
          label: '创建时间',
          align: 'center',
          slot: 'createTime',
          showOverflowTooltip: true,
          minWidth: 120,
        },
        {
          prop: 'status',
          label: '计划状态',
          align: 'center',
          slot: 'status',
          showOverflowTooltip: true,
          formatter: (_row, _column, cellValue) => {
            return this.statusList[_row.status].label;
          },
          minWidth: 120,
        },
        {
          prop: 'processStatus',
          label: '状态',
          align: 'center',
          showOverflowTooltip: true,
          minWidth: 100,
          formatter: (_row, _column, cellValue) => {
            return reviewStatusEnum[_row.processStatus].label;
          }
        },
        {
          columnKey: 'action',
          label: '操作',
          width: 180,
          align: 'center',
          resizable: false,
          slot: 'action',
          showOverflowTooltip: true,
          fixed: 'right'
        }
      ]
    }
  },
  created() {
  },
  methods: {
    //新增、修改
    handleAddOrEdit(row = {}, type) {
      this.addOrEditDialogFlag = true
      this.$nextTick(() => {
        this.$refs.addOrEditDialogRef.init(row, type)
      })
    },
    //详情
    handleDetail(row = {}, type) {
      this.detailDialogFlag = true
      this.$nextTick(() => {
        this.$refs.detailDialogRef.init(row, type)
      })
    },
    //派单
    async handleDispatch(row) {
      await logistictrakplanDistributionAPI([row.id])
      this.$message.success('派单成功！');
      this.reload();
    },
    //撤回
    async handleWithdraw(row) {
      await logistictrakplanwithdrawAPI({id:row.id,status:0})
      this.$message.success('撤销成功！');
      this.reload();
    },
    /* 表格数据源 */
    datasource({page, limit, where, order}) {
      return logistictrakplanPageListAPI({
        pageNum: page,
        size: limit,
        ...where
      });
    },

    /* 刷新表格 */
    reload(where) {
      this.$nextTick(() => {
        this.$refs.table.reload({page: 1, where});
      })
    },

    //批量删除
    allDelBtn() {
      if (this.selection.length === 0) return;
      let flag = this.selection.some(item => [1, 2].includes(item.approvalStatus))
      if (flag) return this.$message.warning('抱歉已审核、审核中的数据不能删除,请检查')
      this.delVisible = true;
    },

    commitBtn() {
      const dataId = this.selection.map((v) => v.id);
      logistictrakplanRemoveAPI(dataId).then((res) => {
        this.$message.success('删除成功！');
        this.reload();
      });
    },
    remove(row) {
      logistictrakplanRemoveAPI(row).then((res) => {
        this.$message.success('删除成功！');
        this.reload();
      });
    },

    sub(res) {
      logisticSubmit({
        businessId: res.id,
        planId: res.id
      })
        .then((res) => {
          this.$message.success('提交成功');
          this.reload();
        })
        .catch((e) => {
          this.$message.error(e.message);
        });
    },
  }
};
</script>

<style lang="scss" scoped>
:deep(.el-link--inner) {
  margin-left: 0px !important;
}

.sys-organization-list {
  height: calc(100vh - 264px);
  box-sizing: border-box;
  border-width: 1px;
  border-style: solid;
  overflow: auto;
}

.sys-organization-list :deep(.el-tree-node__content) {
  height: 40px;

  & > .el-tree-node__expand-icon {
    margin-left: 10px;
  }
}
</style>
